/// Model class for mapping the json returned by the https://www.insmet.cu
/// weather API
class WeatherModel {
  String cityName;
  final days = List<WeatherDayModel>();

  /// Class constructor
  WeatherModel(this.cityName, List<String> data)
      : assert(data != null && data.length >= 20) {
    for (var i = 0; i < data.length; i += 4) {
      days.add(WeatherDayModel(
        day: int.parse(data[i]),
        max: int.parse(data[i + 1]),
        min: int.parse(data[i + 2]),
        description: data[i + 3],
      ));
    }
  }

  @override
  String toString() {
    var result = StringBuffer();
    result.write('City Name: $cityName\n');
    for (var i = 0; i < days.length; ++i) {
      result.write('${days[i]}');
      if (i + 1 < days.length) {
        result.write('\n');
      }
    }
    return result.toString();
  }
}

/// Model class for mapping part of the json returned by the
/// https://www.insmet.cu weather API
class WeatherDayModel {
  int day;
  int max;
  int min;
  State state;
  String description;

  /// Class constructor
  WeatherDayModel({this.day, this.max, this.min, this.description}) {
    state = dictStringToState[description];
  }

  @override
  String toString() {
    return 'Day: $day, Maximum Temperature: $max°C, '
        'Minimum Temperature: $min°C, State: $state, Description: $description';
  }
}

enum State {
  OccasionalShowers,
  ScatteredShowers,
  IsolatedShowers,
  AfternoonShowers,
  RainShowers,
  PartlyCloudy,
  Cloudy,
  Sunny,
  Storms,
  AfternoonStorms,
}

final dictStringToState = {
  'Lluvias Ocasionales': State.OccasionalShowers,
  'Lluvias dispersas': State.ScatteredShowers,
  'Lluvias aisladas': State.IsolatedShowers,
  'Lluvias en la Tarde': State.AfternoonShowers,
  'Chubascos': State.RainShowers,
  'Parcialmente Nublado': State.PartlyCloudy,
  'Nublado': State.Cloudy,
  'Soleado': State.Sunny,
  'Tormentas': State.Storms,
  'Tormentas en la Tarde': State.AfternoonStorms,
};
